@@ -51,4 +51,14 @@ test_that("canGetPageSource", {
   remDr$navigate(loadPage("simpleTest"))
   source <- remDr$getPageSource()
   expect_true(grepl("html", source[[1]]))
-})
\ No newline at end of file
+})
+
+test_that("canSetExtraCaps", {
+  prefs = list("profile.managed_default_content_settings.images" = 2L)
+  cprof <- list(chromeOptions = list(prefs = prefs)) 
+  expect_output(
+    init2 <- initFun(silent = FALSE, extraCapabilities = cprof)
+  )
+  on.exit(init2$remDr$close())
+  expect_identical(init2$remDr$extraCapabilities, cprof)
+})
